function [Z1,Er1,Z2,Er2]=compar_methode_newton(A,x0,n)

% compar_methode_newton : calcul de racine carres de A par mthode de Newton.
% 
% *********************************************************
%
% [Z1,Er1,Z2,Er2]=compar_methode_newton(A,x0,n)
% permet de calculer la racine de A par la mthode de newton
% usuelle et la mthode modifie : 
% on part de x0 infrieur  sqrt(3/A) et on 
% calcule y_n :
% y_{n+1}=(y_n*(3-A*y_n^2))/2 avec A y_n qui tend vers sqrt(A).
%
%	variables d'entres : 
%    * A et x_0 deux rels strictement positifs
%    * n : entier naturel 
%
%	variables de sortie
%     * Z1 et Z2 :  valeurs x_n et A*y_n des itrs des methodes
%                   de newton usuelle et mofifie.
%     * Er1 et Er2 : les deux erreurs abs(x_n^2-A) et abs((A*x_n)^2-A)
%                    correspondant aux deux mthodes
% 
% ************ Fonctions auxiliaires utilises ************
%
%       aucune
%
% *********************************************************


Z1=zeros(n+1,1);
Z2=zeros(n+1,1);
Z1(1)=x0;
Z2(1)=x0;
xA=x0;
xB=x0;
for i=1:n
   xA=(xA+A/xA)/2;
   xB=xB*(3-A*(xB^2))/2;
   Z1(i+1)=xA;
   Z2(i+1)=xB;
end
Er1=abs(Z1.^2-A);
Z2=A*Z2;
Er2=abs(Z2.^2-A);
